#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 FindBin
version:              0.0.5
visibility:           public
id:                   FindBin-0.0.5-EhAvW7cp7hN7H2og3pFxaA
key:                  FindBin-0.0.5-EhAvW7cp7hN7H2og3pFxaA
license:              BSD-3-Clause
copyright:            2008-2011 Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang <audreyt@audreyt.org>
stability:            Stable
homepage:             https://github.com/audreyt/findbin
synopsis:             Locate directory of original program
description:
    This module locates the full directory to the running program,
    to allow the use of paths relative to it.
    FindBin supports invocation of Haskell programs via "ghci",
    via "runhaskell/runghc", as well as compiled as an executable.

category:             System
abi:                  1113540661783632b96ccb292b2c869a
exposed:              True
exposed-modules:      System.Environment.FindBin
import-dirs:          /usr/lib/ghc-8.10.5/site-local/FindBin-0.0.5
library-dirs:         /usr/lib/ghc-8.10.5/site-local/FindBin-0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/FindBin-0.0.5
hs-libraries:         HSFindBin-0.0.5-EhAvW7cp7hN7H2og3pFxaA
depends:              base-4.14.2.0 directory-1.3.6.0 filepath-1.4.2.1
haddock-interfaces:   /usr/share/doc/haskell-findbin/html/FindBin.haddock
haddock-html:         /usr/share/doc/haskell-findbin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

